==> lxqt-admin_0.16.0.orig.tar.xz: lxqt-admin-0.16.0/lxqt-admin-user/translations/lxqt-admin-user_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Groepsinstellingen</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Groepsnaam:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Groeps-ID:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Gebruikers behoren tot deze groep:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>De groepsnaam kan niet leeg zijn.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Instellingen voor gebruikers en groepen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Gebruikers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Aanmeldnaam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>Gebruikers-ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Volledige naam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Thuismap</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Toon systeemgebruikers (alleen voor gevorderden)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Groepen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>Groeps-ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Leden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Edit properties of the selected item</source>
        <translation>Bewerk eigenschappen van het geselecteerde item</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add new users or groups</source>
        <translation>Nieuwe gebruikers of groepen toevoegen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete selected item</source>
        <translation>Verwijder gekozen element</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Refresh</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh the lists</source>
        <translation>Ververs de lijsten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="206"/>
        <source>Change Password</source>
        <translation>Wachtwoord wijzigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Change password for the selected user or group</source>
        <translation>Wijzig wachtwoord voor de gekozen gebruiker of groep</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Confirm</source>
        <translation>Bevestigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Wilt u de gekozen gebruiker werkelijk verwijderen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Wilt u de gekozen groep werkelijk verwijderen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Input the new password for %1:</source>
        <translation>Geef het nieuwe wachtwoord in voor %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Weet u zeker dat u een leeg wachtwoord wilt instellen?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Gebruikersinstellingen</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Volledige naam:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Aanmeldnaam:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Gebruikers-ID:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Hoofdgroep:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Groepen</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>De gebruiker behoort tot de volgende groepen:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Aanmeldschil:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Thuismap:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>De gebruikersnaam kan niet leeg zijn.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="227"/>
        <source>lxqt-admin-user</source>
        <translation>lxqt-admin-user</translation>
    </message>
    <message>
        <location filename="../usermanager.cpp" line="228"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Actie (%1) mislukt:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-admin_1.1.0.orig.tar.xz: lxqt-admin-1.1.0/lxqt-admin-user/translations/lxqt-admin-user_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Groepsinstellingen</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Groepsnaam:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Groepsid:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Gebruikers behoren tot deze groep:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Voer een groepsnaam in.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Gebruikers- en groepsinstellingen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>Gebr&amp;uikers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Aanmeldnaam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>Gebruikersid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Volledige naam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Persoonlijke map</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Systeemgebruikers tonen (alleen voor gevorderden)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Groepen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>Groepsid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Leden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Edit properties of the selected item</source>
        <translation>Eigenschappen van het geselecteerde item bewerken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add new users or groups</source>
        <translation>Voeg nieuwe gebruikers of groepen toe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete selected item</source>
        <translation>Verwijder het geselecteerde item</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Refresh</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh the lists</source>
        <translation>Ververs de lijsten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="206"/>
        <source>Change Password</source>
        <translation>Wachtwoord wijzigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Change password for the selected user or group</source>
        <translation>Wijzig het wachtwoord van de geselecteerde gebruiker of groep</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Confirm</source>
        <translation>Bevestigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Weet u zeker dat u de geselecteerde gebruiker wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Weet u zeker dat u de geselecteerde groep wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Input the new password for %1:</source>
        <translation>Voer een nieuw wachtwoord in voor %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Weet u zeker dat u een blanco wachtwoord wilt instellen?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Gebruikersinstellingen</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Volledige naam:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Aanmeldnaam:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Gebruikersid:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Hoofdgroep:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Groepen</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>Deze gebruiker behoort tot de volgende groepen:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Aanmeldschil:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Persoonlijke map:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>Voer een gebruikersnaam in.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="227"/>
        <source>lxqt-admin-user</source>
        <translation>lxqt-admin-user</translation>
    </message>
    <message>
        <location filename="../usermanager.cpp" line="228"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Actie (%1) mislukt:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
